==> hs-hxt-9.2.2_1.tbz: lib/ghc-7.4.1/cabal/hxt-9.2.2/register.sh <==
#!/bin/sh
echo 'name: hxt
version: 9.2.2
id: hxt-9.2.2-f9655e4c08b015519d10ad17aa697bbb

license: MIT
copyright: Copyright (c) 2005-2012 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: http://www.fh-wedel.de/~si/HXmlToolbox/index.html
package-url:
synopsis: A collection of tools for processing XML with Haskell.
description: The Haskell XML Toolbox bases on the ideas of HaXml and HXML,
             but introduces a more general approach for processing XML with Haskell.
             The Haskell XML Toolbox uses a generic data model for representing XML documents,
             including the DTD subset and the document subset, in Haskell.
             It contains a validating XML parser, a HTML parser, namespace support,
             an XPath expression evaluator, an XSLT library, a RelaxNG schema validator
             and funtions for serialization and deserialization of user defined data.
             The library makes extensive use of the arrow approach for processing XML.
             Since version 9 the toolbox is partitioned into various (sub-)packages.
             This package contains the core functionality,
             hxt-curl, hxt-tagsoup, hxt-relaxng, hxt-xpath, hxt-xslt, hxt-regex-xmlschema contain the extensions.
             hxt-unicode contains encoding and decoding functions,
             hxt-charproperties char properties for unicode and XML.
             .
             Changes to 9.2.1: user defined mime type handlers added
             .
             Changes to 9.2.0: New warnings from ghc-7.4 removed
category: XML
author: Uwe Schmidt, Martin Schmidt, Torben Kuseler
exposed: True
exposed-modules: Control.Arrow.ArrowExc Control.Arrow.ArrowIO
                 Control.Arrow.ArrowIf Control.Arrow.ArrowList Control.Arrow.ArrowNF
                 Control.Arrow.ArrowNavigatableTree Control.Arrow.ArrowState
                 Control.Arrow.ArrowTree Control.Arrow.IOListArrow
                 Control.Arrow.IOStateListArrow Control.Arrow.ListArrow
                 Control.Arrow.ListArrows Control.Arrow.NTreeEdit
                 Control.Arrow.StateListArrow Control.FlatSeq Data.AssocList
                 Data.Atom Data.Function.Selector Data.Tree.Class
                 Data.Tree.NTree.TypeDefs Data.Tree.NTree.Edit
                 Data.Tree.NTree.Zipper.TypeDefs Data.Tree.NavigatableTree.Class
                 Data.Tree.NavigatableTree.XPathAxis Text.XML.HXT.Arrow.Binary
                 Text.XML.HXT.Arrow.DTDProcessing Text.XML.HXT.Arrow.DocumentInput
                 Text.XML.HXT.Arrow.DocumentOutput Text.XML.HXT.Arrow.Edit
                 Text.XML.HXT.Arrow.GeneralEntitySubstitution
                 Text.XML.HXT.Arrow.Namespace Text.XML.HXT.Arrow.ParserInterface
                 Text.XML.HXT.Arrow.Pickle Text.XML.HXT.Arrow.Pickle.DTD
                 Text.XML.HXT.Arrow.Pickle.Schema Text.XML.HXT.Arrow.Pickle.Xml
                 Text.XML.HXT.Arrow.ProcessDocument Text.XML.HXT.Arrow.ReadDocument
                 Text.XML.HXT.Arrow.WriteDocument Text.XML.HXT.Arrow.XmlArrow
                 Text.XML.HXT.Arrow.XmlOptions Text.XML.HXT.Arrow.XmlRegex
                 Text.XML.HXT.Arrow.XmlState
                 Text.XML.HXT.Arrow.XmlState.ErrorHandling
                 Text.XML.HXT.Arrow.XmlState.MimeTypeTable
                 Text.XML.HXT.Arrow.XmlState.RunIOStateArrow
                 Text.XML.HXT.Arrow.XmlState.TraceHandling
                 Text.XML.HXT.Arrow.XmlState.TypeDefs
                 Text.XML.HXT.Arrow.XmlState.URIHandling
                 Text.XML.HXT.Arrow.XmlState.SystemConfig Text.XML.HXT.Core
                 Text.XML.HXT.DOM.FormatXmlTree Text.XML.HXT.DOM.Interface
                 Text.XML.HXT.DOM.MimeTypeDefaults Text.XML.HXT.DOM.MimeTypes
                 Text.XML.HXT.DOM.QualifiedName Text.XML.HXT.DOM.ShowXml
                 Text.XML.HXT.DOM.TypeDefs Text.XML.HXT.DOM.Util
                 Text.XML.HXT.DOM.XmlKeywords Text.XML.HXT.DOM.XmlNode
                 Text.XML.HXT.DTDValidation.AttributeValueValidation
                 Text.XML.HXT.DTDValidation.DTDValidation
                 Text.XML.HXT.DTDValidation.DocTransformation
                 Text.XML.HXT.DTDValidation.DocValidation
                 Text.XML.HXT.DTDValidation.IdValidation
                 Text.XML.HXT.DTDValidation.RE Text.XML.HXT.DTDValidation.TypeDefs
                 Text.XML.HXT.DTDValidation.Validation
                 Text.XML.HXT.DTDValidation.XmlRE Text.XML.HXT.IO.GetFILE
                 Text.XML.HXT.Parser.HtmlParsec
                 Text.XML.HXT.Parser.ProtocolHandlerUtil
                 Text.XML.HXT.Parser.XhtmlEntities Text.XML.HXT.Parser.XmlCharParser
                 Text.XML.HXT.Parser.XmlDTDParser
                 Text.XML.HXT.Parser.XmlDTDTokenParser
                 Text.XML.HXT.Parser.XmlEntities Text.XML.HXT.Parser.XmlParsec
                 Text.XML.HXT.Parser.XmlTokenParser
                 Text.XML.HXT.XMLSchema.DataTypeLibW3CNames Text.XML.HXT.Version
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/hxt-9.2.2
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/hxt-9.2.2
              /usr/local/lib
hs-libraries: HShxt-9.2.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: HUnit-1.2.4.2-6a8472ae640062c77c1c8e76fa6e1bb9
         base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         binary-0.5.1.0-7100f639c59068a2d40264555b8517e7
         bytestring-0.9.2.1-e2bcd9910229fcb291a3a8dd6f79f7fe
         containers-0.4.2.1-7c54595400348f577b3b4a45691c5afd
         deepseq-1.3.0.0-6c19ec61ee16184ee322c1614ab60f0e
         directory-1.1.0.2-295465228776dcfcc680f61dc2cbcb59
         filepath-1.3.0.0-674b8a582fb49f1c9724f50a6a5d5768
         hxt-charproperties-9.1.1-4bb740c52fee26bdca2ea9364d9d55c4
         hxt-regex-xmlschema-9.0.4-cf5992357fa86d15dfb49cb9c5f55cc1
         hxt-unicode-9.0.2-db7ea691cc8adf61718902f249b9e76d
         mtl-2.1.1-ae9b44386a2528180e60dcf2412689c0
         network-2.3.0.13-61384c729042da4a510c1f2707b5d629
         parsec-3.1.2-5d1caf26bfa3bdcc843000f0803b4975
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/hxt-9.2.2/html/hxt.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/hxt-9.2.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-hxt-9.3.1.1_2.tbz: lib/ghc-7.4.2/cabal/hxt-9.3.1.1/register.sh <==
#!/bin/sh
echo 'name: hxt
version: 9.3.1.1
id: hxt-9.3.1.1-98c26a68ea5fc92eb87bee3499a7175f

license: MIT
copyright: Copyright (c) 2005-2012 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: http://www.fh-wedel.de/~si/HXmlToolbox/index.html
package-url:
synopsis: A collection of tools for processing XML with Haskell.
description: The Haskell XML Toolbox bases on the ideas of HaXml and HXML,
             but introduces a more general approach for processing XML with Haskell.
             The Haskell XML Toolbox uses a generic data model for representing XML documents,
             including the DTD subset and the document subset, in Haskell.
             It contains a validating XML parser, a HTML parser, namespace support,
             an XPath expression evaluator, an XSLT library, a RelaxNG schema validator
             and funtions for serialization and deserialization of user defined data.
             The library makes extensive use of the arrow approach for processing XML.
             Since version 9 the toolbox is partitioned into various (sub-)packages.
             This package contains the core functionality,
             hxt-curl, hxt-tagsoup, hxt-relaxng, hxt-xpath, hxt-xslt, hxt-regex-xmlschema contain the extensions.
             hxt-unicode contains encoding and decoding functions,
             hxt-charproperties char properties for unicode and XML.
             .
             Changes from 9.3.1.0: in readString all input decoding switched off
             .
             Changes from 9.3.0.1: lower bound for network set to be >= 2.4
             .
             Changes from 9.3.0: upper bound for network set to be < 2.4 (URI signatures changed in 2.4)
             .
             Changes from 9.2.2: XMLSchema validation integrated
             .
             Changes from 9.2.1: user defined mime type handlers added
             .
             Changes from 9.2.0: New warnings from ghc-7.4 removed
category: XML
author: Uwe Schmidt, Martin Schmidt, Torben Kuseler
exposed: True
exposed-modules: Control.Arrow.ArrowExc Control.Arrow.ArrowIO
                 Control.Arrow.ArrowIf Control.Arrow.ArrowList Control.Arrow.ArrowNF
                 Control.Arrow.ArrowNavigatableTree Control.Arrow.ArrowState
                 Control.Arrow.ArrowTree Control.Arrow.IOListArrow
                 Control.Arrow.IOStateListArrow Control.Arrow.ListArrow
                 Control.Arrow.ListArrows Control.Arrow.NTreeEdit
                 Control.Arrow.StateListArrow Control.FlatSeq Data.AssocList
                 Data.Atom Data.Function.Selector Data.Tree.Class
                 Data.Tree.NTree.TypeDefs Data.Tree.NTree.Edit
                 Data.Tree.NTree.Zipper.TypeDefs Data.Tree.NavigatableTree.Class
                 Data.Tree.NavigatableTree.XPathAxis Text.XML.HXT.Arrow.Binary
                 Text.XML.HXT.Arrow.DTDProcessing Text.XML.HXT.Arrow.DocumentInput
                 Text.XML.HXT.Arrow.DocumentOutput Text.XML.HXT.Arrow.Edit
                 Text.XML.HXT.Arrow.GeneralEntitySubstitution
                 Text.XML.HXT.Arrow.Namespace Text.XML.HXT.Arrow.ParserInterface
                 Text.XML.HXT.Arrow.Pickle Text.XML.HXT.Arrow.Pickle.DTD
                 Text.XML.HXT.Arrow.Pickle.Schema Text.XML.HXT.Arrow.Pickle.Xml
                 Text.XML.HXT.Arrow.ProcessDocument Text.XML.HXT.Arrow.ReadDocument
                 Text.XML.HXT.Arrow.WriteDocument Text.XML.HXT.Arrow.XmlArrow
                 Text.XML.HXT.Arrow.XmlOptions Text.XML.HXT.Arrow.XmlRegex
                 Text.XML.HXT.Arrow.XmlState
                 Text.XML.HXT.Arrow.XmlState.ErrorHandling
                 Text.XML.HXT.Arrow.XmlState.MimeTypeTable
                 Text.XML.HXT.Arrow.XmlState.RunIOStateArrow
                 Text.XML.HXT.Arrow.XmlState.TraceHandling
                 Text.XML.HXT.Arrow.XmlState.TypeDefs
                 Text.XML.HXT.Arrow.XmlState.URIHandling
                 Text.XML.HXT.Arrow.XmlState.SystemConfig Text.XML.HXT.Core
                 Text.XML.HXT.DOM.FormatXmlTree Text.XML.HXT.DOM.Interface
                 Text.XML.HXT.DOM.MimeTypeDefaults Text.XML.HXT.DOM.MimeTypes
                 Text.XML.HXT.DOM.QualifiedName Text.XML.HXT.DOM.ShowXml
                 Text.XML.HXT.DOM.TypeDefs Text.XML.HXT.DOM.Util
                 Text.XML.HXT.DOM.XmlKeywords Text.XML.HXT.DOM.XmlNode
                 Text.XML.HXT.DTDValidation.AttributeValueValidation
                 Text.XML.HXT.DTDValidation.DTDValidation
                 Text.XML.HXT.DTDValidation.DocTransformation
                 Text.XML.HXT.DTDValidation.DocValidation
                 Text.XML.HXT.DTDValidation.IdValidation
                 Text.XML.HXT.DTDValidation.RE Text.XML.HXT.DTDValidation.TypeDefs
                 Text.XML.HXT.DTDValidation.Validation
                 Text.XML.HXT.DTDValidation.XmlRE Text.XML.HXT.IO.GetFILE
                 Text.XML.HXT.Parser.HtmlParsec
                 Text.XML.HXT.Parser.ProtocolHandlerUtil
                 Text.XML.HXT.Parser.XhtmlEntities Text.XML.HXT.Parser.XmlCharParser
                 Text.XML.HXT.Parser.XmlDTDParser
                 Text.XML.HXT.Parser.XmlDTDTokenParser
                 Text.XML.HXT.Parser.XmlEntities Text.XML.HXT.Parser.XmlParsec
                 Text.XML.HXT.Parser.XmlTokenParser
                 Text.XML.HXT.XMLSchema.DataTypeLibW3CNames Text.XML.HXT.Version
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/hxt-9.3.1.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/hxt-9.3.1.1
              /usr/local/lib
hs-libraries: HShxt-9.3.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: HUnit-1.2.5.1-3a320959e06d702551395cbe60e9b4d5
         base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         binary-0.5.1.0-9002afa60235020869a5f21683c71666
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         deepseq-1.3.0.0-c26e15897417ecd448742528253d68f6
         directory-1.1.0.2-9e375ee7bfb1a0ae28bfd926af73e15a
         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
         hxt-charproperties-9.1.1-cea6b380d4b974fb0906a001577b8958
         hxt-regex-xmlschema-9.1.0-f7c83ceacd7976e382b2dd8a015ae550
         hxt-unicode-9.0.2-5951b33371e8f7ff59f42c2bb84d4a6c
         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
         network-2.3.1.0-6b6d66ee2df4c4f37033da9ed9847211
         parsec-3.1.3-5f7c2da354dce0be86cf682bae60efdd
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/hxt-9.3.1.1/html/hxt.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/hxt-9.3.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
